Module read_guard
gil
0.8.0
Module read_
guard
Module Items
Structs
Traits
In crate gil
gil
Module
read_
guard
Structs

Read
Guard
RAII guard for batch read operations on a queue receiver.
Traits

Batch
Reader
Trait for queue receivers that support batch read operations.